<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * MonsterInsights PPC Tracking Provider base class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ad_Providers
 * @author  David Paternina
 */
abstract class MonsterInsights_PPC_Tracking_Provider
{
    /**
     * Provider constructor
     */
    public function __construct() {
        $this->init();
    }

    /**
     * Initialize Provider
     *
     * @since 2.0.0
     * @return void
     */
    protected function init() {
        if ( !$this->is_active() ) {
            return;
        }

        //  Add instance frontend hooks
        $this->add_frontend_hooks();
    }

    /**
     * Checks if the provider is active from MI settings panel
     *
     * @since 2.0.0
     * @return string
     */
    abstract public function is_active();

    /**
     * Get the provider id
     *
     * @since 2.0.0
     * @return string
     */
    abstract public function get_provider_id();

    /**
     * Register the Provider's frontend hooks
     *
     * This function is used to load the required scripts in the frontend
     *
     * @since 2.0.0
     * @return void
     */
    abstract protected function add_frontend_hooks();

    /**
     * Prints the necessary script for conversion tracking.
     * This should be agnostic to ecommerce platforms.
     *
     * Returns true if conversion code is print in the page, false otherwise
     *
     * @return boolean
     */
    abstract public function maybe_print_conversion_code($conversion_data);
}