<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * MonsterInsights PPC Tracking - Restrict Content Pro tracking class.
 *
 * @access public
 * @since 2.0.0
 *
 * @package MonsterInsights_PPC_Tracking
 * @subpackage Ecommerce_Providers
 * @author  David Paternina
 */

class MonsterInsights_PPC_Tracking_Ecommerce_RCP extends MonsterInsights_PPC_Tracking_Ecommerce_Tracking
{
    /**
     * RCP Payment
     *
     * @var $payment RCP_Payments
     */
    protected $payment;

    /**
     * @inheritdoc
     */
    public function do_conversion_checks() {
        global $post;
        global $rcp_options;

        $current_page_id      = $post->ID;
        $rcp_welcome_page_id = $rcp_options['redirect'];

        if ( absint( $current_page_id ) !== absint( $rcp_welcome_page_id ) ) {
            return false;
        }

        return true;
    }

    /**
     * @inheritdoc
     */
    public function is_active() {
        return class_exists( 'Restrict_Content_Pro' ) &&
            version_compare( RCP_PLUGIN_VERSION, '3.5.4', '>=' ) &&
            apply_filters( 'MonsterInsights_PPC_Tracking_track_conversion_rcp', true );
    }

    /**
     * @inheritdoc
     */
    public function try_to_get_order() {
        $customer = rcp_get_customer();

        //  Get the latest payment
        $payments = $customer->get_payments(array(
            'number'    => 1,
            'order'     => 'DESC',
            'orderby'   => 'id',
        ));

        if ( empty( $payments ) ) {
            return false;
        }

        $payment = $payments[0];

        if ( $payment->transaction_type === 'renewal' ) {
            return false;
        }

        $this->payment = $payment;
        return true;
    }

    /**
     * @inheritDoc
     */
    function get_order_total() {
        return empty( $this->payment ) ? null : $this->payment->amount;
    }

    /**
     * @inheritDoc
     */
    function get_order_currency() {
        return empty( $this->payment ) || !function_exists('rcp_get_currency') ? null : rcp_get_currency();
    }

    /**
     * @inheritDoc
     */
    function get_order_number() {
        return empty( $this->payment ) ? null : $this->payment->id;
    }

    /**
     * @inheritDoc
     */
    function already_tracked( $provider_id ) {
        if ( empty( $this->payment ) ) {
            return true;
        }

        $rcp_payments = new RCP_Payments();

        $tracked = $rcp_payments->get_meta(
            $this->get_order_number(),
            "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}",
            true
        );

        return ! empty( $tracked ) && 'yes' === $tracked;
    }

    /**
     * @inheritDoc
     */
    function mark_order_tracked( $provider_id ) {
        if ( empty( $this->payment ) ) {
            return;
        }

        $rcp_payments = new RCP_Payments();

        $rcp_payments->update_meta(
            $this->get_order_number(),
            "_MonsterInsights_PPC_Tracking_conversion_tracked_{$provider_id}",
            'yes'
        );
    }

    /**
     * @inheritdoc
     */
    public function get_name()
    {
        return 'RCP';
    }
}
